==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/functions_69.js <==
var searchData=
[
  ['image',['image',['../classplstream.html#ac989af8edc268809f0356dcdab357d52',1,'plstream::image()'],['../classplplot_1_1core_1_1PLStream.html#a060eb0129a73940e21b731c94fa7457e',1,'plplot.core.PLStream.image()']]],
  ['imagefr',['imagefr',['../classplstream.html#a1825d1b85354dc79d63c943ff76db65e',1,'plstream::imagefr()'],['../classplplot_1_1core_1_1PLStream.html#af8382e9c383797d39f5c13f59f8d2256',1,'plplot.core.PLStream.imagefr()']]],
  ['incref',['incref',['../classoctave__swig__type.html#a64ae757eedc5f059251018c956ecaad9',1,'octave_swig_type']]],
  ['info',['info',['../classPlframe_1_1Plframe.html#a15e75bd26482f60d1fec6b508f57fe74',1,'Plframe.Plframe.info()'],['../plframe_8c.html#a50c476c18237dbe503b742280c871ef5',1,'Info(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#aeac011e55dd3e84095873f641e88414c',1,'Info(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a123889ddb27f740080ec2f085d8d6a75',1,'Info(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a5ed0f896dcc670084371ae4687ef42c2',1,'Info(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['init',['init',['../classplstream.html#ab6fae273970fc2ea6be2b806959df986',1,'plstream::init()'],['../classplplot_1_1core_1_1PLStream.html#a271a21c0e4f75889e84897380db3a09a',1,'plplot.core.PLStream.init()']]],
  ['init_5fby_5farray',['init_by_array',['../mt19937ar_8c.html#ac1283f9b1ed571332f5ffe53545ffc16',1,'init_by_array(unsigned long init_key[], int key_length):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ac1283f9b1ed571332f5ffe53545ffc16',1,'init_by_array(unsigned long init_key[], int key_length):&#160;mt19937ar.c']]],
  ['init_5fgenrand',['init_genrand',['../mt19937ar_8c.html#a57af1d02a3fb56a949fb4c258f0bc066',1,'init_genrand(unsigned long s):&#160;mt19937ar.c'],['../mt19937ar_8h.html#a57af1d02a3fb56a949fb4c258f0bc066',1,'init_genrand(unsigned long s):&#160;mt19937ar.c']]],
  ['initgcw',['initgcw',['../gcwmodule_8c.html#acbac66efba0b75d79ce1a64ca8c8f328',1,'gcwmodule.c']]],
  ['initplplot_5fwidget',['initplplot_widget',['../plplot__widgetmodule_8c.html#a18c528d058ef76e80f11e719370a1a88',1,'plplot_widgetmodule.c']]],
  ['initqtapp',['initQtApp',['../qt_8cpp.html#a79cbaf64e5e613990121aeac156f5ef1',1,'qt.cpp']]],
  ['initstream',['InitStream',['../classwxPLplotstream.html#a6f04fc1acbc1841d5f3f2ef2201013c9',1,'wxPLplotstream']]],
  ['install_5fbuffer',['install_buffer',['../wxwidgets_8cpp.html#acd4cd83ecd8b88e96df62fdc051ab46c',1,'wxwidgets.cpp']]],
  ['install_5fcmap',['Install_cmap',['../plframe_8c.html#a6952d9613b6b763d3108fe06c2bad005',1,'Install_cmap(PlFrame *plFramePtr):&#160;plframe.c'],['../plplotter_8c.html#a46c777dcf3c32cf5c1f543e9a0df5d1f',1,'Install_cmap(PlPlotter *plPlotterPtr):&#160;plplotter.c']]],
  ['interpolate_5fbetween',['interpolate_between',['../plline_8c.html#afc8f2329abf040f0cc9b6402c60a3d2d',1,'plline.c']]],
  ['is_5fdefined',['is_defined',['../classoctave__swig__type.html#a4772d58fd8aea9e15112bb386c04e141',1,'octave_swig_type::is_defined()'],['../classoctave__swig__ref.html#ad0be9f0b9a7211f76f1d74b2387abee2',1,'octave_swig_ref::is_defined()'],['../classoctave__swig__packed.html#a82c103aaa18661196c1a0d834bbba958',1,'octave_swig_packed::is_defined()']]],
  ['is_5fglobal',['is_global',['../structswig__octave__member.html#af054ce79b5e314c3b9c3b8f82d47a8e7',1,'swig_octave_member']]],
  ['is_5fmap',['is_map',['../classoctave__swig__type.html#ad477e6b46bb4ee5c874911ab7f580056',1,'octave_swig_type::is_map()'],['../classoctave__swig__ref.html#aabbba912b76c95875b7f3f2b00f4943f',1,'octave_swig_ref::is_map()']]],
  ['is_5fobject',['is_object',['../classoctave__swig__type.html#a601c5e717a067c5882dbc892772fd27b',1,'octave_swig_type::is_object()'],['../classoctave__swig__ref.html#aee25e59fe7854513bd5be1d0f2481c96',1,'octave_swig_ref::is_object()']]],
  ['is_5fowned',['is_owned',['../classoctave__swig__type.html#affda9e5851516e4b29f4d27a7fec8ada',1,'octave_swig_type']]],
  ['is_5fstatic',['is_static',['../structswig__octave__member.html#a7bad3ea669530c227bf37c260d55e0f5',1,'swig_octave_member']]],
  ['is_5fstring',['is_string',['../classoctave__swig__type.html#ab1e954a0b9b96dcefc0662c0306cd45b',1,'octave_swig_type::is_string()'],['../classoctave__swig__ref.html#ad624a96aa92b137a4154822bb66ff0ef',1,'octave_swig_ref::is_string()']]],
  ['ismasterdevice',['isMasterDevice',['../classMasterHandler.html#a2ac354d153daf16d666971f3399d0c74',1,'MasterHandler']]],
  ['istack_5fcontains',['istack_contains',['../istack_8c.html#a7bd9c14b31f2d2a9a14edc72126c0d75',1,'istack_contains(istack *s, int v):&#160;istack.c'],['../istack_8h.html#a7bd9c14b31f2d2a9a14edc72126c0d75',1,'istack_contains(istack *s, int v):&#160;istack.c']]],
  ['istack_5fcreate',['istack_create',['../istack_8c.html#a4a933af886f0805e60e8a754fab206a2',1,'istack_create():&#160;istack.c'],['../istack_8h.html#af544578deb302b2a8829181c1a945a30',1,'istack_create(void):&#160;istack.c']]],
  ['istack_5fdestroy',['istack_destroy',['../istack_8c.html#af4fef0b85ed8fa7d807df0d3334f2324',1,'istack_destroy(istack *s):&#160;istack.c'],['../istack_8h.html#af4fef0b85ed8fa7d807df0d3334f2324',1,'istack_destroy(istack *s):&#160;istack.c']]],
  ['istack_5finit',['istack_init',['../istack_8c.html#acdf9bf33b9f339b888d9d9e014707a35',1,'istack.c']]],
  ['istack_5fpop',['istack_pop',['../istack_8c.html#aaddb8fb58de4453ef51e883e2c06ce30',1,'istack_pop(istack *s):&#160;istack.c'],['../istack_8h.html#aaddb8fb58de4453ef51e883e2c06ce30',1,'istack_pop(istack *s):&#160;istack.c']]],
  ['istack_5fpush',['istack_push',['../istack_8c.html#a1f34826db048ca3f9dea5842ecf6c5de',1,'istack_push(istack *s, int v):&#160;istack.c'],['../istack_8h.html#a1f34826db048ca3f9dea5842ecf6c5de',1,'istack_push(istack *s, int v):&#160;istack.c']]],
  ['istack_5freset',['istack_reset',['../istack_8c.html#a6da0da5f0950c9c3d84ee68af56b64e0',1,'istack_reset(istack *s):&#160;istack.c'],['../istack_8h.html#a6da0da5f0950c9c3d84ee68af56b64e0',1,'istack_reset(istack *s):&#160;istack.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/functions_69.js <==
var searchData=
[
  ['image',['image',['../classplstream.html#ac989af8edc268809f0356dcdab357d52',1,'plstream::image()'],['../classplplot_1_1core_1_1PLStream.html#a060eb0129a73940e21b731c94fa7457e',1,'plplot.core.PLStream.image()']]],
  ['imagefr',['imagefr',['../classplstream.html#a1825d1b85354dc79d63c943ff76db65e',1,'plstream::imagefr()'],['../classplplot_1_1core_1_1PLStream.html#af8382e9c383797d39f5c13f59f8d2256',1,'plplot.core.PLStream.imagefr()']]],
  ['importbuffer',['ImportBuffer',['../classwxPLplotstream.html#ae85b3bbc1674165634d5577460926efc',1,'wxPLplotstream']]],
  ['incref',['incref',['../classoctave__swig__type.html#a64ae757eedc5f059251018c956ecaad9',1,'octave_swig_type']]],
  ['info',['info',['../classPlframe_1_1Plframe.html#a15e75bd26482f60d1fec6b508f57fe74',1,'Plframe.Plframe.info()'],['../plframe_8c.html#a50c476c18237dbe503b742280c871ef5',1,'Info(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#aeac011e55dd3e84095873f641e88414c',1,'Info(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a123889ddb27f740080ec2f085d8d6a75',1,'Info(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a5ed0f896dcc670084371ae4687ef42c2',1,'Info(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['init',['init',['../classplstream.html#ab6fae273970fc2ea6be2b806959df986',1,'plstream::init()'],['../classplplot_1_1core_1_1PLStream.html#a271a21c0e4f75889e84897380db3a09a',1,'plplot.core.PLStream.init()']]],
  ['init_5fby_5farray',['init_by_array',['../mt19937ar_8c.html#ac1283f9b1ed571332f5ffe53545ffc16',1,'init_by_array(unsigned long init_key[], int key_length):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ac1283f9b1ed571332f5ffe53545ffc16',1,'init_by_array(unsigned long init_key[], int key_length):&#160;mt19937ar.c']]],
  ['init_5fgenrand',['init_genrand',['../mt19937ar_8c.html#a57af1d02a3fb56a949fb4c258f0bc066',1,'init_genrand(unsigned long s):&#160;mt19937ar.c'],['../mt19937ar_8h.html#a57af1d02a3fb56a949fb4c258f0bc066',1,'init_genrand(unsigned long s):&#160;mt19937ar.c']]],
  ['init_5fplplotqt_5fsmoke',['init_plplotqt_Smoke',['../plplotqt__smoke_8h.html#a9a04c24fc4db970e8f8abaebcee55c9e',1,'plplotqt_smoke.h']]],
  ['initplplot_5fwidget',['initplplot_widget',['../plplot__widgetmodule_8c.html#a18c528d058ef76e80f11e719370a1a88',1,'plplot_widgetmodule.c']]],
  ['initqtapp',['initQtApp',['../qt_8cpp.html#a79cbaf64e5e613990121aeac156f5ef1',1,'qt.cpp']]],
  ['initstream',['InitStream',['../classwxPLplotstream.html#a6f04fc1acbc1841d5f3f2ef2201013c9',1,'wxPLplotstream']]],
  ['install_5fcmap',['Install_cmap',['../plframe_8c.html#a6952d9613b6b763d3108fe06c2bad005',1,'Install_cmap(PlFrame *plFramePtr):&#160;plframe.c'],['../plplotter_8c.html#a46c777dcf3c32cf5c1f543e9a0df5d1f',1,'Install_cmap(PlPlotter *plPlotterPtr):&#160;plplotter.c']]],
  ['interpolate_5fbetween',['interpolate_between',['../plline_8c.html#afc8f2329abf040f0cc9b6402c60a3d2d',1,'plline.c']]],
  ['is_5fdefined',['is_defined',['../classoctave__swig__type.html#a4772d58fd8aea9e15112bb386c04e141',1,'octave_swig_type::is_defined()'],['../classoctave__swig__ref.html#ad0be9f0b9a7211f76f1d74b2387abee2',1,'octave_swig_ref::is_defined()'],['../classoctave__swig__packed.html#a82c103aaa18661196c1a0d834bbba958',1,'octave_swig_packed::is_defined()']]],
  ['is_5fglobal',['is_global',['../structswig__octave__member.html#af054ce79b5e314c3b9c3b8f82d47a8e7',1,'swig_octave_member']]],
  ['is_5fmap',['is_map',['../classoctave__swig__type.html#ad477e6b46bb4ee5c874911ab7f580056',1,'octave_swig_type::is_map()'],['../classoctave__swig__ref.html#aabbba912b76c95875b7f3f2b00f4943f',1,'octave_swig_ref::is_map()']]],
  ['is_5fobject',['is_object',['../classoctave__swig__type.html#a601c5e717a067c5882dbc892772fd27b',1,'octave_swig_type::is_object()'],['../classoctave__swig__ref.html#aee25e59fe7854513bd5be1d0f2481c96',1,'octave_swig_ref::is_object()']]],
  ['is_5fowned',['is_owned',['../classoctave__swig__type.html#affda9e5851516e4b29f4d27a7fec8ada',1,'octave_swig_type']]],
  ['is_5fstatic',['is_static',['../structswig__octave__member.html#a7bad3ea669530c227bf37c260d55e0f5',1,'swig_octave_member']]],
  ['is_5fstring',['is_string',['../classoctave__swig__type.html#ab1e954a0b9b96dcefc0662c0306cd45b',1,'octave_swig_type::is_string()'],['../classoctave__swig__ref.html#ad624a96aa92b137a4154822bb66ff0ef',1,'octave_swig_ref::is_string()']]],
  ['iseverythingclipped',['isEverythingClipped',['../classClipper.html#a1e8475a919c2d133ae79e127fd26e43a',1,'Clipper']]],
  ['ismasterdevice',['isMasterDevice',['../classMasterHandler.html#a2ac354d153daf16d666971f3399d0c74',1,'MasterHandler']]],
  ['istack_5fcontains',['istack_contains',['../istack_8c.html#a7bd9c14b31f2d2a9a14edc72126c0d75',1,'istack_contains(istack *s, int v):&#160;istack.c'],['../istack_8h.html#a7bd9c14b31f2d2a9a14edc72126c0d75',1,'istack_contains(istack *s, int v):&#160;istack.c']]],
  ['istack_5fcreate',['istack_create',['../istack_8c.html#a4a933af886f0805e60e8a754fab206a2',1,'istack_create():&#160;istack.c'],['../istack_8h.html#af544578deb302b2a8829181c1a945a30',1,'istack_create(void):&#160;istack.c']]],
  ['istack_5fdestroy',['istack_destroy',['../istack_8c.html#af4fef0b85ed8fa7d807df0d3334f2324',1,'istack_destroy(istack *s):&#160;istack.c'],['../istack_8h.html#af4fef0b85ed8fa7d807df0d3334f2324',1,'istack_destroy(istack *s):&#160;istack.c']]],
  ['istack_5finit',['istack_init',['../istack_8c.html#acdf9bf33b9f339b888d9d9e014707a35',1,'istack.c']]],
  ['istack_5fpop',['istack_pop',['../istack_8c.html#aaddb8fb58de4453ef51e883e2c06ce30',1,'istack_pop(istack *s):&#160;istack.c'],['../istack_8h.html#aaddb8fb58de4453ef51e883e2c06ce30',1,'istack_pop(istack *s):&#160;istack.c']]],
  ['istack_5fpush',['istack_push',['../istack_8c.html#a1f34826db048ca3f9dea5842ecf6c5de',1,'istack_push(istack *s, int v):&#160;istack.c'],['../istack_8h.html#a1f34826db048ca3f9dea5842ecf6c5de',1,'istack_push(istack *s, int v):&#160;istack.c']]],
  ['istack_5freset',['istack_reset',['../istack_8c.html#a6da0da5f0950c9c3d84ee68af56b64e0',1,'istack_reset(istack *s):&#160;istack.c'],['../istack_8h.html#a6da0da5f0950c9c3d84ee68af56b64e0',1,'istack_reset(istack *s):&#160;istack.c']]],
  ['isvalid',['isValid',['../classPLMemoryMap.html#a8530cbc6bee6a665688c062cfdf185a2',1,'PLMemoryMap::isValid()'],['../classPLNamedMutex.html#acdc69696d8ee5d77366ab26a2c1df08a',1,'PLNamedMutex::isValid()'],['../classwxPLplotstream.html#a8dc34d31354c81c13d933efd702c8dec',1,'wxPLplotstream::IsValid()']]]
];
